@@ -1,15 +1,25 @@
 #!/bin/sh
 #
 # autogen.sh glue for pxlib
-# $Id: autogen.sh,v 1.8 2005/08/22 15:05:45 steinm Exp $
+# $Id: autogen.sh,v 1.9 2007/09/12 15:31:50 steinm Exp $
 #
 # Requires: automake, autoconf, dpkg-dev
 set -e
 
-intltoolize --force --copy
+# Refresh GNU autotools toolchain.
+for i in config.guess config.sub missing install-sh mkinstalldirs ; do
+	test -r /usr/share/automake/${i} && {
+		rm -f ${i}
+		cp /usr/share/automake/${i} .
+	}
+	chmod 755 ${i}
+done
+
+libtoolize --force --copy
 aclocal
 autoheader
 automake --verbose --copy --force --add-missing
+intltoolize --force --copy
 autoconf
 
 # For the Debian build
