@@ -8,7 +8,8 @@
  * Default error handler if not set by application
  */
 void px_errorhandler(pxdoc_t *p, int error, const char *str, void *data) {
-	printf("PXLib: %s\n", str);
+	if(error != PX_Warning || p->warnings == px_true)
+		printf("PXLib: %s\n", str);
 }
 /* }}} */
 
@@ -22,14 +23,8 @@ void px_error(pxdoc_t *p, int type, const char *fmt, ...) {
 	va_start(ap, fmt);
 	vsprintf(msg, fmt, ap);
 
-	if (!p->in_error) {
-		p->in_error = 1; /* avoid recursive errors */
-		if(p->errorhandler)
-			(p->errorhandler)(p, type, msg, p->errorhandler_user_data);
-	}
-
-	/* If the error handler returns the error was non-fatal */
-	p->in_error = 0;
+	if(p->errorhandler)
+		(p->errorhandler)(p, type, msg, p->errorhandler_user_data);
 
 	va_end(ap);
 }
