@@ -1,5 +1,8 @@
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include "px_intern.h"
 #include "paradox.h"
